warning off all

% sets the path
cd PUT YOUR PATH HERE

% If you want a diary, uncomment what follows and give it a name
%delete('my_log.out');
%diary('my_log.out');

format long;




disp('%%%%%%%%');
disp('est_a_1');
disp('%%%%%%%%');

% input data
clear
All1 = load( 'data/est_strg_1' );
include = All1.include;
x = All1.x;
gamma = All1.gamma;
p = All1.p;
x_M = All1.x_M;
vc_bs = All1.vc_bs;
freq_e_bs = All1.freq_e_bs;

% play with results
x = [gamma; p(1:end-1)];

% standard errors
std = sqrt(diag(vc_bs));

% display basic results
foo = [-999, include]';
bar = [x; p(end)];
baz = [sqrt(diag(vc_bs)); -999];
[foo, bar, baz]
beta = 1 / ( 1 + exp( -1 / x(1) ) )

% load elicited strategies
plus = load( 'data/ac_strg_1_special_plus.txt' );
strg_e = plus(:,[1:end]);
strg_e = strg_e(:, include);

% display basic results about elicitation
other = 1-sum(mean(strg_e(:, include)))


disp(' ');
disp('Tests equality to elicited proportions using the waldtest');
disp('------------------------');

for i = 2:length(include)
    [ws wp] = wald_plus(x_M, [i], freq_e_bs(:,i-1), vc_bs);
    disp(' ');
    if abs(x(i)-mean(strg_e(:,i-1))) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: %1.3f',include(i-1),mean(strg_e(:,i-1)),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(i-1),mean(strg_e(:,i-1))));
    end
end
[ws wp] = wald_plus(x_M, [0,ones(1,length(include)-1)], 1-freq_e_bs(:,i), vc_bs);
if abs(p(end)-mean(strg_e(:,i))) > eps
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: %1.3f',include(end),mean(strg_e(:,i)),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(end),mean(strg_e(:,i))));
end

disp(' ');
disp('Joint test');
disp('----------');

[ws wp] = wald_plus(x_M, [zeros(1,length(include)); zeros(length(include)-1,1), eye(length(include)-1)], freq_e_bs(:,[1:end-1]), vc_bs);
disp(' ');
disp(sprintf('p-value of phis = elicited value: %1.3f',1-wp));
disp(' ');
%%%%%% Because of problems that can arise at the border of the space, let's
%%%%%% drop strategies with estimates really close to 0
include_foo = [1,3,4,5];
x_M_foo = x_M(include_foo,:);
freq_e_bs_foo = freq_e_bs(:,include_foo);
vc_bs_foo = vc_bs([1,2,4,5],[1,2,4,5]);
[ws wp] = wald_plus(x_M_foo, [zeros(1,length(include_foo)); zeros(length(include_foo)-1,1), eye(length(include_foo)-1)], freq_e_bs_foo(:,[1:end-1]), vc_bs_foo);
disp(' ');
disp(sprintf('p-value of phis (dropping 0s) = elicited value: %1.3f',1-wp));
disp(' ');



disp(' ');
disp('Tests equality to 0 using the waldtest');
disp('------------------------');

[ws wp] = waldtest_gf(x, [1], 0, vc_bs);
disp(' ');
disp(sprintf('p-value of gamma = 0: %1.3f',1-wp));
for i = 2:length(include)
    [ws wp] = waldtest_gf(x, [i], 0, vc_bs);
    if x(i) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: %1.3f',include(i-1),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(i-1)));
    end
end
if p(end) > eps
    [ws wp] = waldtest_gf(x, [0,ones(1,length(include)-1)], 1, vc_bs);
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: %1.3f',include(end),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(end)));
end




disp('%%%%%%%%');
disp('est_a_2');
disp('%%%%%%%%');

% input data
clear
All2 = load( 'data/est_strg_2' );
include = All2.include;
x = All2.x;
gamma = All2.gamma;
p = All2.p;
x_M = All2.x_M;
vc_bs = All2.vc_bs;
freq_e_bs = All2.freq_e_bs;

% play with results
x = [gamma; p(1:end-1)];

% standard errors
std = sqrt(diag(vc_bs));

% display basic results
foo = [-999, include]';
bar = [x; p(end)];
baz = [sqrt(diag(vc_bs)); -999];
[foo, bar, baz]
beta = 1 / ( 1 + exp( -1 / x(1) ) )

% load elicited strategies
plus = load( 'data/ac_strg_2_special_plus.txt' );
strg_e = plus(:,[1:end]);
strg_e = strg_e(:, include);

% display basic results about elicitation
other = 1-sum(mean(strg_e(:, include)))


disp(' ');
disp('Tests equality to elicited proportions using the waldtest');
disp('------------------------');

for i = 2:length(include)
    [ws wp] = wald_plus(x_M, [i], freq_e_bs(:,i-1), vc_bs);
    disp(' ');
    if abs(x(i)-mean(strg_e(:,i-1))) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: %1.3f',include(i-1),mean(strg_e(:,i-1)),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(i-1),mean(strg_e(:,i-1))));
    end
end
[ws wp] = wald_plus(x_M, [0,ones(1,length(include)-1)], 1-freq_e_bs(:,i), vc_bs);
if abs(p(end)-mean(strg_e(:,i))) > eps
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: %1.3f',include(end),mean(strg_e(:,i)),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(end),mean(strg_e(:,i))));
end

disp(' ');
disp('Joint test');
disp('----------');

[ws wp] = wald_plus(x_M, [zeros(1,length(include)); zeros(length(include)-1,1), eye(length(include)-1)], freq_e_bs(:,[1:end-1]), vc_bs);
disp(' ');
disp(sprintf('p-value of phis = elicited value: %1.3f',1-wp));
disp(' ');
%%%%%% Because of problems that can arise at the border of the space, let's
%%%%%% drop strategies with estimates really close to 0
include_foo = [1:5];
x_M_foo = x_M(include_foo,:);
freq_e_bs_foo = freq_e_bs(:,include_foo);
vc_bs_foo = vc_bs([1:5],[1:5]);
[ws wp] = wald_plus(x_M_foo, [zeros(1,length(include_foo)); zeros(length(include_foo)-1,1), eye(length(include_foo)-1)], freq_e_bs_foo(:,[1:end-1]), vc_bs_foo);
disp(' ');
disp(sprintf('p-value of phis (dropping 0s) = elicited value: %1.3f',1-wp));
disp(' ');


disp(' ');
disp('Tests equality to 0 using the waldtest');
disp('------------------------');

[ws wp] = waldtest_gf(x, [1], 0, vc_bs);
disp(' ');
disp(sprintf('p-value of gamma = 0: %1.3f',1-wp));
for i = 2:length(include)
    [ws wp] = waldtest_gf(x, [i], 0, vc_bs);
    if x(i) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: %1.3f',include(i-1),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(i-1)));
    end
end
if p(end) > eps
    [ws wp] = waldtest_gf(x, [0,ones(1,length(include)-1)], 1, vc_bs);
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: %1.3f',include(end),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(end)));
end





disp('%%%%%%%%');
disp('est_a_3');
disp('%%%%%%%%');

% input data
clear
All3 = load( 'data/est_strg_3' );
include = All3.include;
x = All3.x;
gamma = All3.gamma;
p = All3.p;
x_M = All3.x_M;
vc_bs = All3.vc_bs;
freq_e_bs = All3.freq_e_bs;

% play with results
x = [gamma; p(1:end-1)];

% standard errors
std = sqrt(diag(vc_bs));

% display basic results
foo = [-999, include]';
bar = [x; p(end)];
baz = [sqrt(diag(vc_bs)); -999];
[foo, bar, baz]
beta = 1 / ( 1 + exp( -1 / x(1) ) )

% load elicited strategies
plus = load( 'data/ac_strg_3_special_plus.txt' );
strg_e = plus(:,[1:end]);
strg_e = strg_e(:, include);

% display basic results about elicitation
other = 1-sum(mean(strg_e(:, include)))


disp(' ');
disp('Tests equality to elicited proportions using the waldtest');
disp('------------------------');

for i = 2:length(include)
    [ws wp] = wald_plus(x_M, [i], freq_e_bs(:,i-1), vc_bs);
    disp(' ');
    if abs(x(i)-mean(strg_e(:,i-1))) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: %1.3f',include(i-1),mean(strg_e(:,i-1)),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(i-1),mean(strg_e(:,i-1))));
    end
end
[ws wp] = wald_plus(x_M, [0,ones(1,length(include)-1)], 1-freq_e_bs(:,i), vc_bs);
if abs(p(end)-mean(strg_e(:,i))) > eps
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: %1.3f',include(end),mean(strg_e(:,i)),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(end),mean(strg_e(:,i))));
end

disp(' ');
disp('Joint test');
disp('----------');

[ws wp] = wald_plus(x_M, [zeros(1,length(include)); zeros(length(include)-1,1), eye(length(include)-1)], freq_e_bs(:,[1:end-1]), vc_bs);
disp(' ');
disp(sprintf('p-value of phis = elicited value: %1.3f',1-wp));
disp(' ');
%%%%%% Because of problems that can arise at the border of the space, let's
%%%%%% drop strategies with estimates really close to 0
include_foo = [1:5];
x_M_foo = x_M(include_foo,:);
freq_e_bs_foo = freq_e_bs(:,include_foo);
vc_bs_foo = vc_bs([1:5],[1:5]);
[ws wp] = wald_plus(x_M_foo, [zeros(1,length(include_foo)); zeros(length(include_foo)-1,1), eye(length(include_foo)-1)], freq_e_bs_foo(:,[1:end-1]), vc_bs_foo);
disp(' ');
disp(sprintf('p-value of phis (dropping 0s) = elicited value: %1.3f',1-wp));
disp(' ');



disp(' ');
disp('Tests equality to 0 using the waldtest');
disp('------------------------');

[ws wp] = waldtest_gf(x, [1], 0, vc_bs);
disp(' ');
disp(sprintf('p-value of gamma = 0: %1.3f',1-wp));
for i = 2:length(include)
    [ws wp] = waldtest_gf(x, [i], 0, vc_bs);
    if x(i) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: %1.3f',include(i-1),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(i-1)));
    end
end
if p(end) > eps
    [ws wp] = waldtest_gf(x, [0,ones(1,length(include)-1)], 1, vc_bs);
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: %1.3f',include(end),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(end)));
end





disp('%%%%%%%%');
disp('est_a_4');
disp('%%%%%%%%');

% input data
clear
All4 = load( 'data/est_strg_4' );
include = All4.include;
x = All4.x;
gamma = All4.gamma;
p = All4.p;
x_M = All4.x_M;
vc_bs = All4.vc_bs;
freq_e_bs = All4.freq_e_bs;

% play with results
x = [gamma; p(1:end-1)];

% standard errors
std = sqrt(diag(vc_bs));

% display basic results
foo = [-999, include]';
bar = [x; p(end)];
baz = [sqrt(diag(vc_bs)); -999];
[foo, bar, baz]
beta = 1 / ( 1 + exp( -1 / x(1) ) )

% load elicited strategies
plus = load( 'data/ac_strg_4_special_plus.txt' );
strg_e = plus(:,[1:end]);
strg_e = strg_e(:, include);

% display basic results about elicitation
other = 1-sum(mean(strg_e(:, include)))


disp(' ');
disp('Tests equality to elicited proportions using the waldtest');
disp('------------------------');

for i = 2:length(include)
    [ws wp] = wald_plus(x_M, [i], freq_e_bs(:,i-1), vc_bs);
    disp(' ');
    if abs(x(i)-mean(strg_e(:,i-1))) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: %1.3f',include(i-1),mean(strg_e(:,i-1)),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(i-1),mean(strg_e(:,i-1))));
    end
end
[ws wp] = wald_plus(x_M, [0,ones(1,length(include)-1)], 1-freq_e_bs(:,i), vc_bs);
if abs(p(end)-mean(strg_e(:,i))) > eps
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: %1.3f',include(end),mean(strg_e(:,i)),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(end),mean(strg_e(:,i))));
end

disp(' ');
disp('Joint test');
disp('----------');

[ws wp] = wald_plus(x_M, [zeros(1,length(include)); zeros(length(include)-1,1), eye(length(include)-1)], freq_e_bs(:,[1:end-1]), vc_bs);
disp(' ');
disp(sprintf('p-value of phis = elicited value: %1.3f',1-wp));
disp(' ');

%%%%%% Because of problems that can arise at the border of the space, let's
%%%%%% drop strategies with estimates really close to 0
include_foo = [1:5];
x_M_foo = x_M(include_foo,:);
freq_e_bs_foo = freq_e_bs(:,include_foo);
vc_bs_foo = vc_bs([1:5],[1:5]);
[ws wp] = wald_plus(x_M_foo, [zeros(1,length(include_foo)); zeros(length(include_foo)-1,1), eye(length(include_foo)-1)], freq_e_bs_foo(:,[1:end-1]), vc_bs_foo);
disp(' ');
disp(sprintf('p-value of phis (dropping 0s) = elicited value: %1.3f',1-wp));
disp(' ');


disp(' ');
disp('Tests equality to 0 using the waldtest');
disp('------------------------');

[ws wp] = waldtest_gf(x, [1], 0, vc_bs);
disp(' ');
disp(sprintf('p-value of gamma = 0: %1.3f',1-wp));
for i = 2:length(include)
    [ws wp] = waldtest_gf(x, [i], 0, vc_bs);
    if x(i) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: %1.3f',include(i-1),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(i-1)));
    end
end
if p(end) > eps
    [ws wp] = waldtest_gf(x, [0,ones(1,length(include)-1)], 1, vc_bs);
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: %1.3f',include(end),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(end)));
end





disp('%%%%%%%%');
disp('est_a_5');
disp('%%%%%%%%');

% input data
clear
All5 = load( 'data/est_strg_5' );
include = All5.include;
x = All5.x;
gamma = All5.gamma;
p = All5.p;
x_M = All5.x_M;
vc_bs = All5.vc_bs;
freq_e_bs = All5.freq_e_bs;

% play with results
x = [gamma; p(1:end-1)];

% standard errors
std = sqrt(diag(vc_bs));

% display basic results
foo = [-999, include]';
bar = [x; p(end)];
baz = [sqrt(diag(vc_bs)); -999];
[foo, bar, baz]
beta = 1 / ( 1 + exp( -1 / x(1) ) )

% load elicited strategies
plus = load( 'data/ac_strg_5_special_plus.txt' );
strg_e = plus(:,[1:end]);
strg_e = strg_e(:, include);

% display basic results about elicitation
other = 1-sum(mean(strg_e(:, include)))


disp(' ');
disp('Tests equality to elicited proportions using the waldtest');
disp('------------------------');

for i = 2:length(include)
    [ws wp] = wald_plus(x_M, [i], freq_e_bs(:,i-1), vc_bs);
    disp(' ');
    if abs(x(i)-mean(strg_e(:,i-1))) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: %1.3f',include(i-1),mean(strg_e(:,i-1)),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(i-1),mean(strg_e(:,i-1))));
    end
end
[ws wp] = wald_plus(x_M, [0,ones(1,length(include)-1)], 1-freq_e_bs(:,i), vc_bs);
if abs(p(end)-mean(strg_e(:,i))) > eps
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: %1.3f',include(end),mean(strg_e(:,i)),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = %f: Cannot reject H0',include(end),mean(strg_e(:,i))));
end

disp(' ');
disp('Joint test');
disp('----------');

[ws wp] = wald_plus(x_M, [zeros(1,length(include)); zeros(length(include)-1,1), eye(length(include)-1)], freq_e_bs(:,[1:end-1]), vc_bs);
disp(' ');
disp(sprintf('p-value of phis = elicited value: %1.3f',1-wp));
disp(' ');
%%%%%% Because of problems that can arise at the border of the space, let's
%%%%%% drop strategies with estimates really close to 0
include_foo = [1:5];
x_M_foo = x_M(include_foo,:);
freq_e_bs_foo = freq_e_bs(:,include_foo);
vc_bs_foo = vc_bs([1:5],[1:5]);
[ws wp] = wald_plus(x_M_foo, [zeros(1,length(include_foo)); zeros(length(include_foo)-1,1), eye(length(include_foo)-1)], freq_e_bs_foo(:,[1:end-1]), vc_bs_foo);
disp(' ');
disp(sprintf('p-value of phis (dropping 0s) = elicited value: %1.3f',1-wp));
disp(' ');



disp(' ');
disp('Tests equality to 0 using the waldtest');
disp('------------------------');

[ws wp] = waldtest_gf(x, [1], 0, vc_bs);
disp(' ');
disp(sprintf('p-value of gamma = 0: %1.3f',1-wp));
for i = 2:length(include)
    [ws wp] = waldtest_gf(x, [i], 0, vc_bs);
    if x(i) > eps
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: %1.3f',include(i-1),1-wp));
    else
       disp(' ');
       disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(i-1)));
    end
end
if p(end) > eps
    [ws wp] = waldtest_gf(x, [0,ones(1,length(include)-1)], 1, vc_bs);
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: %1.3f',include(end),1-wp));
else
    disp(' ');
    disp(sprintf('p-value of phi %d = 0: Cannot reject H0',include(end)));
end


disp('------------------------');
disp('------------------------');
disp('------------------------');

%%%%%%%%%%%%%
% Figure out sample size for text
disp(' ');
All = load( 'data/dfformatlab_strg_1_special.txt' );
disp(sprintf('Sample size for treatment 1: %d',length(All(:,4))));
disp(' ');
All = load( 'data/dfformatlab_strg_2_special.txt' );
disp(sprintf('Sample size for treatment 2: %d',length(All(:,4))));
disp(' ');
All = load( 'data/dfformatlab_strg_3_special.txt' );
disp(sprintf('Sample size for treatment 3: %d',length(All(:,4))));
disp(' ');
All = load( 'data/dfformatlab_strg_4_special.txt' );
disp(sprintf('Sample size for treatment 2: %d',length(All(:,4))));
disp(' ');
All = load( 'data/dfformatlab_strg_5_special.txt' );
disp(sprintf('Sample size for treatment 3: %d',length(All(:,4))));

diary off

