function [coop, match, id, strg] = sim_data_jel( beta, coop_rate, num_ad, num_g, num_tft, num_ad_g, num_ad_tft, num_g_tft, num_match, delta )

% This function generates the data

% Adapted from the exercise we did for the JEL piece to determine if we
% could recover the popularity of strategies if subjects were allowed to
% mix over strategies. That file is df_jel/m/sim_sfem_test.m and it was
% itself a modification of df_strat/m/est_flag_1.m.

% Idea is to simulate 1 subject playing supergames against a
% random device that cooperates at some given rate (coop_rate).

% I will only have three strategies: AD, G, and TFT.

% beta is the probability that the choice coincides with the one prescribed by the strategy.
% rate of cooperation of opponent.
% number of subjects that use AD
% number of subjects that use G
% number of subjects that use TFT
% number of subjects that use AD half the time and G the other half
% number of subjects that use AD half the time and TFT the other half
% number of subjects that use G half the time and TFT the other half

% Check that match is even (only because if num_ad_g, num_af_tft, or
% num_g_tft are non zero the match number is divided in two)
if mod(num_match,2) ~= 0 & (num_ad_g > 0 | num_ad_tft > 0 | num_g_tft > 0 )
    error('num_mactch needs to be even');
    return
end

% initialize variables
coop = [];
strg_ad = [];
strg_g = [];
strg_tft = [];
match = [];
round = [];
id = [];
counter = 1;
for j = 1:num_match
    match_length_vec(j,1) = mean(geornd(1-delta,1,1)+1);
end

% subject that uses AD
if num_ad > 0, for k = 1:num_ad
  for j = 1:num_match
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_ad_foo*(rand<=beta) ) + ( (1-strg_ad_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_ad_foo(i,1)*(rand<=beta) ) + ( (1-strg_ad_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
end, else, end

% subject that uses G
if num_g > 0, for k = 1:num_g
  for j = 1:num_match
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_g_foo*(rand<=beta) ) + ( (1-strg_g_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_g_foo(i,1)*(rand<=beta) ) + ( (1-strg_g_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
end, else, end

% subject that uses TFT
if num_tft > 0, for k = 1:num_tft
  for j = 1:num_match
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_tft_foo*(rand<=beta) ) + ( (1-strg_tft_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_tft_foo(i,1)*(rand<=beta) ) + ( (1-strg_tft_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
end, else, end

% subject that uses AD and G
if num_ad_g > 0, for k = 1:num_ad_g
  for j = 1:(num_match/2)
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_ad_foo*(rand<=beta) ) + ( (1-strg_ad_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_ad_foo(i,1)*(rand<=beta) ) + ( (1-strg_ad_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
  for j = (num_match/2)+1:num_match
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_g_foo*(rand<=beta) ) + ( (1-strg_g_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_g_foo(i,1)*(rand<=beta) ) + ( (1-strg_g_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
end, else, end

% subject that uses AD and TFT
if num_ad_tft > 0, for k = 1:num_ad_tft
  for j = 1:(num_match/2)
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_ad_foo*(rand<=beta) ) + ( (1-strg_ad_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_ad_foo(i,1)*(rand<=beta) ) + ( (1-strg_ad_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
  for j = (num_match/2)+1:num_match
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_tft_foo*(rand<=beta) ) + ( (1-strg_tft_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_tft_foo(i,1)*(rand<=beta) ) + ( (1-strg_tft_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
end, else, end

% subject that uses G and TFT
if num_g_tft > 0, for k = 1:num_g_tft
  for j = 1:(num_match/2)
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_g_foo*(rand<=beta) ) + ( (1-strg_g_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_g_foo(i,1)*(rand<=beta) ) + ( (1-strg_g_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
  for j = (num_match/2)+1:num_match
    match_length = match_length_vec(j,1);
    strg_ad_foo = 0;
    strg_g_foo = 1;
    strg_tft_foo = 1;
    coop_foo = ( strg_tft_foo*(rand<=beta) ) + ( (1-strg_tft_foo)*(rand>beta) );
    ocoop_foo = (rand < coop_rate);  % the opponent executes his startegy without errors.
    for i = 2:match_length
      strg_ad_foo(i,1) = 0;
      strg_g_foo(i,1) = ( strg_g_foo(i-1,1)== 1 & coop_foo(i-1,1)==1 & ocoop_foo(i-1,1)==1 );
      strg_tft_foo(i,1) = ( ocoop_foo(i-1,1)==1 );
      coop_foo(i,1) = ( strg_tft_foo(i,1)*(rand<=beta) ) + ( (1-strg_tft_foo(i,1))*(rand>beta) );
      ocoop_foo(i,1) = (rand < coop_rate);
    end
    coop = [coop; coop_foo];
    strg_ad = [strg_ad; strg_ad_foo];
    strg_g = [strg_g; strg_g_foo];
    strg_tft = [strg_tft; strg_tft_foo];
    match = [match; j*ones(match_length,1)];
    round = [round; [1:match_length]'];
    id = [id; counter*ones(match_length,1)];
  end
    counter = counter + 1;
end, else, end

% group strategy variables
strg = [strg_ad strg_g strg_tft];

