function [session, id, match_all, round_all, coop_all, ocoop_all, all_strg_choices, strg_choices, strg_a_all, strg_a_all_m] = simul_data_2(no_session, no_subject, no_match, discount, phi, beta)

% Based on simul_data.m but first adapted for the simulation looking at whether
% it might look like subjects are using memory 1 strategies when in fact
% they are using > memory 1.

% parameters:
%   no_session = number of sessions
%   no_subject = number of subject per session
%   no_match = number of matches
%   discount = discount factor
%   phi = strategy prevealence
%   beta is the probability that the choice coincides withthe one 
%   prescribed by the strategy.
%
% output:
%   session is a session indicator (non-overlaping)
%   id is a subject indicator (non-overlaping)
%   match_all is a match indicator
%   round_all is a round indicator
%   coop_all indicates the choices of the subject in that match and round
%   ocoop_all  is coop_all for the other subject in the pair
%   ...


% initialize variables
subject = [];
osubject = [];
strg_1 = [];
strg_2 = [];
coop = [];
ocoop = [];
coop_all = [];
ocoop_all = [];
match_all = [];
round_all = [];
session = [];
ad_all = [];
ac_all = [];
grim_all = [];
tft_all = [];
stft_all = [];
wsls_all = [];
t2_all = [];
tf2t_all = [];
tf3t_all = [];
s2tft_all = []; % added the leading s because it does not want a name to start with a number
s2tf2t_all = [];
grim2_all = [];
grim3_all = [];
strg_a_all = [];
strg_choices = [];
unique_id = [];

% compute the "cdf" of phi, the cumulative sum of phi
% obtain both the upper and lower bound of each strategy
phi_cum_u = phi;
for i = 2:size(phi,1)
    phi_cum_u(i,1) = phi_cum_u(i,1) + phi_cum_u(i-1,1);
end
phi_cum_l = [0;phi_cum_u(1:size(phi,1)-1)];

for k = 1:no_session
    % forming pairs of subjects every match
    pairings = subjectid_gf(no_subject,no_match);     % each match is a row
    % creating a vector with the strategy of each subject in the session
    foo = rand(no_subject,1);   % random number to pick the elicited strategy
    strg_a = zeros(no_subject,1);   % strg_a for actual
    for j = 1:no_subject
        strg_a(j,1) = find( ( foo(j,1) >= phi_cum_l & foo(j,1) < phi_cum_u ) == 1 );
    end
    clear foo bar baz
    
    % initialize session specific temporary variables
    id_coop = [];
    id_ocoop = [];
    match = [];
    round = [];
    ad = []; ac = []; grim = []; tft = []; stft = []; wsls = []; t2 = []; tf2t = []; tf3t = []; s2tft = []; s2tf2t = []; grim2 = []; grim3 = [];
    strategy = [];
    for j = 1:no_match
        % initialize match specific temporary variables
        length = mean(geornd(1-discount,1,1)+1);
        id_match_coop = -ones(length,no_subject);
        id_match_ocoop = -ones(length,no_subject);
        ad_match = -ones(length,no_subject);
        ac_match = -ones(length,no_subject);
        grim_match = -ones(length,no_subject);
        tft_match = -ones(length,no_subject);
        stft_match = -ones(length,no_subject);
        wsls_match = -ones(length,no_subject);
        t2_match = -ones(length,no_subject);
        tf2t_match = -ones(length,no_subject);
        tf3t_match = -ones(length,no_subject);
        s2tft_match = -ones(length,no_subject);
        s2tf2t_match = -ones(length,no_subject);
        grim2_match = -ones(length,no_subject);
        grim3_match = -ones(length,no_subject);
        strategy_match = -ones(length,no_subject);
        for i = 1:2:no_subject
            subject = pairings(j,i);
            osubject = pairings(j, i+1);
            strg_a_1 = strg_a(subject,1);
            strg_a_2 = strg_a(osubject,1);
            [coop, ocoop, s, os] = strg_choice_2(strg_a_1,strg_a_2,beta,length);
            id_match_coop(:,subject) = coop;
            id_match_coop(:,osubject) = ocoop;
            id_match_ocoop(:,subject) = ocoop;
            id_match_ocoop(:,osubject) = coop;
            ad_match(:,subject) = s(:,1);
            ad_match(:,osubject) = os(:,1);
            ac_match(:,subject) = s(:,2);
            ac_match(:,osubject) = os(:,2);
            grim_match(:,subject) = s(:,3);
            grim_match(:,osubject) = os(:,3);
            tft_match(:,subject) = s(:,4);
            tft_match(:,osubject) = os(:,4);
            stft_match(:,subject) = s(:,5);
            stft_match(:,osubject) = os(:,5);
            wsls_match(:,subject) = s(:,6);
            wsls_match(:,osubject) = os(:,6);
            t2_match(:,subject) = s(:,7);
            t2_match(:,osubject) = os(:,7);
            tf2t_match(:,subject) = s(:,8);
            tf2t_match(:,osubject) = os(:,8);
            tf3t_match(:,subject) = s(:,9);
            tf3t_match(:,osubject) = os(:,9);
            s2tft_match(:,subject) = s(:,10);
            s2tft_match(:,osubject) = os(:,10);
            s2tf2t_match(:,subject) = s(:,11);
            s2tf2t_match(:,osubject) = os(:,11);
            grim2_match(:,subject) = s(:,12);
            grim2_match(:,osubject) = os(:,12);
            grim3_match(:,subject) = s(:,13);
            grim3_match(:,osubject) = os(:,13);
            strategy_match(:,subject) = s(:,strg_a_1);
            strategy_match(:,osubject) = os(:,strg_a_2);
        end
        clear subject osubject strg_a_1 strg_a_2 coop ocoop s os
        
        id_coop = [id_coop; id_match_coop];
        id_ocoop = [id_ocoop; id_match_ocoop];
        match = [match; j*ones(length,1)];
        round = [round; [1:length]'];
        ad = [ad; ad_match];
        ac = [ac; ac_match];
        grim = [grim; grim_match];
        tft = [tft; tft_match];
        stft = [stft; stft_match];
        wsls = [wsls; wsls_match];
        t2 = [t2; t2_match];
        tf2t = [tf2t; tf2t_match];
        tf3t = [tf3t; tf3t_match];
        s2tft = [s2tft; s2tft_match];
        s2tf2t = [s2tf2t; s2tf2t_match];
        grim2 = [grim2; grim2_match];
        grim3 = [grim3; grim3_match];
        strategy = [strategy; strategy_match];
    end
    clear length id_match_coop id_match_ocoop ad_match ac_match grim_match tft_match stft_match wsls_match t2_match tf2t_match tf3t_match s2tft_match s2tf2t_match grim2_match grim3_match strategy_match

    session = [session; k*ones(no_subject*size(match,1),1)];
    unique_id = [unique_id; kron([(k-1)*no_subject+1:(k-1)*no_subject+no_subject]',ones(size(match)))];
    coop_all = [coop_all; reshape(id_coop,[],1)];
    ocoop_all = [ocoop_all; reshape(id_ocoop,[],1)];
    match_all = [match_all; kron(ones(no_subject,1),match)];
    round_all = [round_all; kron(ones(no_subject,1),round)];
    strg_a_all = [strg_a_all; kron(strg_a,ones(size(match)))];
    ad_all = [ad_all; reshape(ad,[],1)];
    ac_all = [ac_all; reshape(ac,[],1)];
    grim_all = [grim_all; reshape(grim,[],1)];
    tft_all = [tft_all; reshape(tft,[],1)];
    stft_all = [stft_all; reshape(stft,[],1)];
    wsls_all = [wsls_all; reshape(wsls,[],1)];
    t2_all = [t2_all; reshape(t2,[],1)];
    tf2t_all = [tf2t_all; reshape(tf2t,[],1)];
    tf3t_all = [tf3t_all; reshape(tf3t,[],1)];
    s2tft_all = [s2tft_all; reshape(s2tft,[],1)];
    s2tf2t_all = [s2tf2t_all; reshape(s2tf2t,[],1)];
    grim2_all = [grim2_all; reshape(grim2,[],1)];
    grim3_all = [grim3_all; reshape(grim3,[],1)];
    strg_choices = [strg_choices; reshape(strategy,[],1)];
end
% reshaping strg_a_all from a vector with the strategy number to a matrix
% taking value one in the column of the relevant strategy
strg_a_all_m = zeros(size(strg_a_all,1),size(phi,1));
for i = 1:size(strg_a_all,1)
    strg_a_all_m(i,strg_a_all(i)) = 1;
end
all_strg_choices = [ad_all, ac_all, grim_all, tft_all, stft_all, wsls_all, t2_all, tf2t_all, tf3t_all, s2tft_all, s2tf2t_all, grim2_all, grim3_all];
id = unique_id;

% Change log
% 07/11/16
%   - Based on simul_data.m to simulate Fudenberg et al. (2012) type data.
%   - Deleted distort and d_type and all if-then conditions based on them.
%   - dropped all references to elicited strategies. Here there's only the
%   actual strategy
%   - Now also keeps track of what these strategies would do: wsls, t2,
%   tf2t, tf3t, 2tft, 2tf2t, grim2, grim3.





