tic

pctRunOnAll warning off all

% sets the path
cd PUT YOUR PATH HERE

% If you want a diary, uncomment what follows and give it a name
%delete('my_log.out');
%diary('my_log.out');
format long;

% clear what's in memory
clear

% set parameters that are fixed in all simulations
num_exp = 10000;  % number of "experiments" for each number of match simulated
num_match = 26;  % number of match per subject

beta = 0.90;    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.
coop_rate = 0.5;    % rate of cooperation of opponent.

num_ad = 0;     % number of subjects that use AD
num_g = 0;      % number of subjects that use G
num_tft = 0;      % number of subjects that use TFT
num_ad_g = 1;      % number of subjects that use AD half the time and G the other half
num_ad_tft = 0;      % number of subjects that use AD half the time and TFT the other half
num_g_tft = 0;      % number of subjects that use G half the time and TFT the other half



%%%%%%%%%%%%%%%%%%%% delta = 1/2 %%%%%%%%%%%%%%%%%%%%

% Set seed
rand('state', 123456789);

% Set parameters
delta = 1/2;    % continuation probability;

% initialize variables
p_mat = zeros(num_match,num_exp);
p_vec_1 = zeros(num_match,1);

%%%%%%%%%%%% SIMULATING THE DATA SET %%%%%%%%%%%%%%%

for j = 2:2:num_match
    j
    for k = 1:num_exp
        
        [coop_all, match, id_all, strg] = sim_data_jel( beta, coop_rate, num_ad, num_g, num_tft, num_ad_g, num_ad_tft, num_g_tft, j, delta );
        
        % generate new vars
        max_id = max(id_all);
        min_id = min(id_all);
        for i = min_id:max_id
            max_match(i) = max(match(find(id_all==i)));
            min_match(i) = min(match(find(id_all==i)));
        end
        K = size(strg,2);
        for i = 1:K
            strg(:,i) = (strg(:,i) == coop_all);     % this transforms strg to take value 1 if choice corresponds to the strategy and 0 otherwise
        end
        
        
        %%%%%%%%%%%% Estimation %%%%%%%%%%%%%%%
        
        superstart = [0.3; 0.33; 0.33];
        
        [x, ll, hess, exitflag] = opt_df_strat(match, min_match, max_match, id_all, min_id, max_id, strg, K, superstart);
        % correct estimate to satisfy constraints used in the m-files for
        % optimization
        if min(x) < 0, foo = x; foo(find(foo>0))=foo(find(foo>0))-(sum(foo(find(foo<0)))/length(find(foo>0)+1)); foo(find(foo<0))=0; x=foo; end
        % play with results
        gamma = x(1,1);
        % negative values should be interpreted as near zero (see ll_part1_b)
        p = x([2:end],1);
        p(K,1) = 1 - sum(x([2:end],1));
        
        p_mat(j,k) = p(2);
    end
end

p_vec_1 = mean(p_mat')'


%%%%%%%%%%%%%%%%%%%% delta = 3/4 %%%%%%%%%%%%%%%%%%%%

% Set seed
rand('state', 123456789);

% Set parameters
delta = 3/4;    % continuation probability;

% initialize variables
p_mat = zeros(num_match,num_exp);
p_vec_2 = zeros(num_match,1);

%%%%%%%%%%%% SIMULATING THE DATA SET %%%%%%%%%%%%%%%

for j = 2:2:num_match
    j
    for k = 1:num_exp
        
        [coop_all, match, id_all, strg] = sim_data_jel( beta, coop_rate, num_ad, num_g, num_tft, num_ad_g, num_ad_tft, num_g_tft, j, delta );
        
        % generate new vars
        max_id = max(id_all);
        min_id = min(id_all);
        for i = min_id:max_id
            max_match(i) = max(match(find(id_all==i)));
            min_match(i) = min(match(find(id_all==i)));
        end
        K = size(strg,2);
        for i = 1:K
            strg(:,i) = (strg(:,i) == coop_all);     % this transforms strg to take value 1 if choice corresponds to the strategy and 0 otherwise
        end
        
        
        %%%%%%%%%%%% Estimation %%%%%%%%%%%%%%%
        
        superstart = [0.3; 0.33; 0.33];
        
        [x, ll, hess, exitflag] = opt_df_strat(match, min_match, max_match, id_all, min_id, max_id, strg, K, superstart);
        % correct estimate to satisfy constraints used in the m-files for
        % optimization
        if min(x) < 0, foo = x; foo(find(foo>0))=foo(find(foo>0))-(sum(foo(find(foo<0)))/length(find(foo>0)+1)); foo(find(foo<0))=0; x=foo; end
        % play with results
        gamma = x(1,1);
        % negative values should be interpreted as near zero (see ll_part1_b)
        p = x([2:end],1);
        p(K,1) = 1 - sum(x([2:end],1));
        
        p_mat(j,k) = p(2);
    end
end

p_vec_2 = mean(p_mat')'


%%%%%%%%%%%%%%%%%%%% delta = 9/10 %%%%%%%%%%%%%%%%%%%%

% Set seed
rand('state', 123456789);

% Set parameters
delta = 9/10;    % continuation probability;

% initialize variables
p_mat = zeros(num_match,num_exp);
p_vec_3 = zeros(num_match,1);

%%%%%%%%%%%% SIMULATING THE DATA SET %%%%%%%%%%%%%%%

for j = 2:2:num_match
    j
    for k = 1:num_exp
        
        [coop_all, match, id_all, strg] = sim_data_jel( beta, coop_rate, num_ad, num_g, num_tft, num_ad_g, num_ad_tft, num_g_tft, j, delta );
        
        % generate new vars
        max_id = max(id_all);
        min_id = min(id_all);
        for i = min_id:max_id
            max_match(i) = max(match(find(id_all==i)));
            min_match(i) = min(match(find(id_all==i)));
        end
        K = size(strg,2);
        for i = 1:K
            strg(:,i) = (strg(:,i) == coop_all);     % this transforms strg to take value 1 if choice corresponds to the strategy and 0 otherwise
        end
        
        
        %%%%%%%%%%%% Estimation %%%%%%%%%%%%%%%
        
        superstart = [0.3; 0.33; 0.33];
        
        [x, ll, hess, exitflag] = opt_df_strat(match, min_match, max_match, id_all, min_id, max_id, strg, K, superstart);
        % correct estimate to satisfy constraints used in the m-files for
        % optimization
        if min(x) < 0, foo = x; foo(find(foo>0))=foo(find(foo>0))-(sum(foo(find(foo<0)))/length(find(foo>0)+1)); foo(find(foo<0))=0; x=foo; end
        % play with results
        gamma = x(1,1);
        % negative values should be interpreted as near zero (see ll_part1_b)
        p = x([2:end],1);
        p(K,1) = 1 - sum(x([2:end],1));
        
        p_mat(j,k) = p(2);
    end
end

p_vec_3 = mean(p_mat')'

%%%%%%%%%%%%%%%%%%%% Putting the stuff together %%%%%%%%%%%%%%%%%%%%

p_results = [p_vec_1, p_vec_2, p_vec_3]

toc

save('data/sim_jel_2.txt', 'p_results', '-ascii', '-double', '-tabs')

diary off
