tic

pctRunOnAll warning off all

% sets the path
cd PUT YOUR PATH HERE

% If you want a diary, uncomment what follows and give it a name
%delete('my_log.out');
%diary('my_log.out');
format long;

% input data
clear


%%%%%%%%%%%% IMPUTING PARAMETERS %%%%%%%%%%%%%%%

% Set seed
rand('state', 123456789);

% parametrized for treatment 2
%
% Set parameters that stay fixed over the different cases (different phi
% and beta)
%
no_session = 5;     % Number of session per treatment
no_subject = 18;    % Number of subject per session
no_match = 20;  % Number of matches
discount = 0.5;  % discount factor

% Number of simulated experiments
no_simul = 1000;

%
% Set parameters for b/c = 2
%
beta = 1 / ( 1 + exp( -1 / 0.5 ) );    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.17;     % fraction of AD - strg_choices = 1
phi_ac = 0.03;         % fraction of AC - strg_choices = 2
phi_grim = 0.07;       % fraction of Grim - strg_choices = 3
phi_tft = 0.06;      % fraction of TFT - strg_choices = 4
phi_stft = 0;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0;
phi_tf3t = 0.03;
phi_2tft = 0.07;
phi_2tf2t = 0.11;
phi_grim2 = 0.18;
phi_grim3 = 0.28;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
x_M = zeros( no_simul , size(phi,1)-2 );

disp('Start Loop 1');
parfor i = 1:no_simul
    [ x ] = sim_power_imp_est( no_session, no_subject, no_match, discount, phi, beta );
    x_M(i,:) = x';
end

output_bc_2 = [x_M];

clearvars -EXCEPT output_bc_2 no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 2.5
%
beta = 1 / ( 1 + exp( -1 / 0.49 ) );    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.14;     % fraction of AD - strg_choices = 1
phi_ac = 0;         % fraction of AC - strg_choices = 2
phi_grim = 0.11;       % fraction of Grim - strg_choices = 3
phi_tft = 0.09;      % fraction of TFT - strg_choices = 4
phi_stft = 0.05;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0.17;
phi_tf3t = 0.05;
phi_2tft = 0.02;
phi_2tf2t = 0.11;
phi_grim2 = 0.02;
phi_grim3 = 0.24;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
x_M = zeros( no_simul , size(phi,1)-2 );

disp('Start Loop 2');
parfor i = 1:no_simul
    [ x ] = sim_power_imp_est( no_session, no_subject, no_match, discount, phi, beta );
    x_M(i,:) = x';
end

output_bc_2p5 = [x_M];

clearvars -EXCEPT output_bc_2 output_bc_2p5 no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 4
%
beta = 1 / ( 1 + exp( -1 / 0.43 ) );    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.23;     % fraction of AD - strg_choices = 1
phi_ac = 0.06;         % fraction of AC - strg_choices = 2
phi_grim = 0.04;       % fraction of Grim - strg_choices = 3
phi_tft = 0.07;      % fraction of TFT - strg_choices = 4
phi_stft = 0;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0.2;
phi_tf3t = 0.09;
phi_2tft = 0.03;
phi_2tf2t = 0.12;
phi_grim2 = 0.05;
phi_grim3 = 0.11;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
x_M = zeros( no_simul , size(phi,1)-2 );

disp('Start Loop 3');
parfor i = 1:no_simul
    [ x ] = sim_power_imp_est( no_session, no_subject, no_match, discount, phi, beta );
    x_M(i,:) = x';
end

output_bc_4 = [x_M];

clearvars -EXCEPT output_bc_2 output_bc_2p5 output_bc_4 no_session no_subject no_match discount no_simul



% Put the key data together
output = [output_bc_2; output_bc_2p5; output_bc_4];



toc

save('data/sim_power_imp_2a', 'output_bc_2', 'output_bc_2p5', 'output_bc_4', '-double', '-tabs')
save('data/sim_power_imp_2a.txt', 'output', '-ascii', '-double', '-tabs')

diary off


