tic

% Based on simul_power_5.m but adapted for the simulation looking at whether
% it might look like subjects are using memory 1 strategies when in fact
% they are using > memory 1.

pctRunOnAll warning off all

% sets the path
cd PUT YOUR PATH HERE

% If you want a diary, uncomment what follows and give it a name
%delete('my_log.out');
%diary('my_log.out');
format long;

% input data
clear


%%%%%%%%%%%% IMPUTING PARAMETERS %%%%%%%%%%%%%%%

% Set seed
rand('state', 123456789);

% parametrized for treatment 5
%
% Set parameters that stay fixed over the different cases (different phi
% and beta)
%
no_session = 5;     % Number of session per treatment
no_subject = 14;    % Number of subject per session
no_match = 4;  % Number of matches
discount = 0.9;  % discount factor

% Number of simulated experiments
no_simul = 1000;

%
% Set parameters for b/c = 2
%
beta = 1 / ( 1 + exp( -1 / 0.5 ) );    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.17;     % fraction of AD - strg_choices = 1
phi_ac = 0.03;         % fraction of AC - strg_choices = 2
phi_grim = 0.07;       % fraction of Grim - strg_choices = 3
phi_tft = 0.06;      % fraction of TFT - strg_choices = 4
phi_stft = 0;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0;
phi_tf3t = 0.03;
phi_2tft = 0.07;
phi_2tf2t = 0.11;
phi_grim2 = 0.18;
phi_grim3 = 0.28;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
frac5_vec = zeros( no_simul , 1);
frac3_vec = zeros( no_simul , 1);

disp('Start Loop 1');
parfor i = 1:no_simul
    [ frac5, frac3 ] = sim_power_imp( no_session, no_subject, no_match, discount, phi, beta );
    if isnan(frac5)==1, frac5 = -1; end,    % This happens if no match is greater than 1 round
    if isnan(frac3)==1, frac3 = -1; end,
    frac5_vec(i,1) = frac5;
    frac3_vec(i,1) = frac3;
end
frac5_vec = frac5_vec(frac5_vec ~= -1); % drop the simulations where all matches have one round
frac3_vec = frac3_vec(frac3_vec ~= -1);

bc = 2*ones(size(frac5_vec));
beta_vec = beta*ones(size(frac5_vec));

output_bc_2 = [bc frac5_vec frac3_vec beta_vec];

clearvars -EXCEPT output_bc_2 no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 2.5
%
beta = 1 / ( 1 + exp( -1 / 0.49 ) );    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.14;     % fraction of AD - strg_choices = 1
phi_ac = 0;         % fraction of AC - strg_choices = 2
phi_grim = 0.11;       % fraction of Grim - strg_choices = 3
phi_tft = 0.09;      % fraction of TFT - strg_choices = 4
phi_stft = 0.05;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0.17;
phi_tf3t = 0.05;
phi_2tft = 0.02;
phi_2tf2t = 0.11;
phi_grim2 = 0.02;
phi_grim3 = 0.24;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
frac5_vec = zeros( no_simul , 1);
frac3_vec = zeros( no_simul , 1);

disp('Start Loop 2');
parfor i = 1:no_simul
    [ frac5, frac3 ] = sim_power_imp( no_session, no_subject, no_match, discount, phi, beta );
    if isnan(frac5)==1, frac5 = -1; end,    % This happens if no match is greater than 1 round
    if isnan(frac3)==1, frac3 = -1; end,
    frac5_vec(i,1) = frac5;
    frac3_vec(i,1) = frac3;
end
frac5_vec = frac5_vec(frac5_vec ~= -1); % drop the simulations where all matches have one round
frac3_vec = frac3_vec(frac3_vec ~= -1);

bc = 2.5*ones(size(frac5_vec));
beta_vec = beta*ones(size(frac5_vec));

output_bc_2p5 = [bc frac5_vec frac3_vec beta_vec];

clearvars -EXCEPT output_bc_2 output_bc_2p5 no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 4
%
beta = 1 / ( 1 + exp( -1 / 0.43 ) );    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.23;     % fraction of AD - strg_choices = 1
phi_ac = 0.06;         % fraction of AC - strg_choices = 2
phi_grim = 0.04;       % fraction of Grim - strg_choices = 3
phi_tft = 0.07;      % fraction of TFT - strg_choices = 4
phi_stft = 0;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0.2;
phi_tf3t = 0.09;
phi_2tft = 0.03;
phi_2tf2t = 0.12;
phi_grim2 = 0.05;
phi_grim3 = 0.11;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
frac5_vec = zeros( no_simul , 1);
frac3_vec = zeros( no_simul , 1);

disp('Start Loop 3');
parfor i = 1:no_simul
    [ frac5, frac3 ] = sim_power_imp( no_session, no_subject, no_match, discount, phi, beta );
    if isnan(frac5)==1, frac5 = -1; end,    % This happens if no match is greater than 1 round
    if isnan(frac3)==1, frac3 = -1; end,
    frac5_vec(i,1) = frac5;
    frac3_vec(i,1) = frac3;
end
frac5_vec = frac5_vec(frac5_vec ~= -1); % drop the simulations where all matches have one round
frac3_vec = frac3_vec(frac3_vec ~= -1);

bc = 4*ones(size(frac5_vec));
beta_vec = beta*ones(size(frac5_vec));

output_bc_4 = [bc frac5_vec frac3_vec beta_vec];

clearvars -EXCEPT output_bc_2 output_bc_2p5 output_bc_4 no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 2 & beta from DF
%
beta = 0.94;    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.17;     % fraction of AD - strg_choices = 1
phi_ac = 0.03;         % fraction of AC - strg_choices = 2
phi_grim = 0.07;       % fraction of Grim - strg_choices = 3
phi_tft = 0.06;      % fraction of TFT - strg_choices = 4
phi_stft = 0;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0;
phi_tf3t = 0.03;
phi_2tft = 0.07;
phi_2tf2t = 0.11;
phi_grim2 = 0.18;
phi_grim3 = 0.28;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
frac5_vec = zeros( no_simul , 1);
frac3_vec = zeros( no_simul , 1);

disp('Start Loop 4');
parfor i = 1:no_simul
    [ frac5, frac3 ] = sim_power_imp( no_session, no_subject, no_match, discount, phi, beta );
    if isnan(frac5)==1, frac5 = -1; end,    % This happens if no match is greater than 1 round
    if isnan(frac3)==1, frac3 = -1; end,
    frac5_vec(i,1) = frac5;
    frac3_vec(i,1) = frac3;
end
frac5_vec = frac5_vec(frac5_vec ~= -1); % drop the simulations where all matches have one round
frac3_vec = frac3_vec(frac3_vec ~= -1);

bc = 2*ones(size(frac5_vec));
beta_vec = beta*ones(size(frac5_vec));

output_bc_2b = [bc frac5_vec frac3_vec beta_vec];

clearvars -EXCEPT output_bc_2 output_bc_2p5 output_bc_4 output_bc_2b no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 2.5 and beta from DF
%
beta = 0.94;    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.14;     % fraction of AD - strg_choices = 1
phi_ac = 0;         % fraction of AC - strg_choices = 2
phi_grim = 0.11;       % fraction of Grim - strg_choices = 3
phi_tft = 0.09;      % fraction of TFT - strg_choices = 4
phi_stft = 0.05;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0.17;
phi_tf3t = 0.05;
phi_2tft = 0.02;
phi_2tf2t = 0.11;
phi_grim2 = 0.02;
phi_grim3 = 0.24;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
frac5_vec = zeros( no_simul , 1);
frac3_vec = zeros( no_simul , 1);

disp('Start Loop 5');
parfor i = 1:no_simul
    [ frac5, frac3 ] = sim_power_imp( no_session, no_subject, no_match, discount, phi, beta );
    if isnan(frac5)==1, frac5 = -1; end,    % This happens if no match is greater than 1 round
    if isnan(frac3)==1, frac3 = -1; end,
    frac5_vec(i,1) = frac5;
    frac3_vec(i,1) = frac3;
end
frac5_vec = frac5_vec(frac5_vec ~= -1); % drop the simulations where all matches have one round
frac3_vec = frac3_vec(frac3_vec ~= -1);

bc = 2.5*ones(size(frac5_vec));
beta_vec = beta*ones(size(frac5_vec));

output_bc_2p5b = [bc frac5_vec frac3_vec beta_vec];

clearvars -EXCEPT output_bc_2 output_bc_2p5 output_bc_4 output_bc_2b output_bc_2p5b no_session no_subject no_match discount no_simul

%
% Set parameters for b/c = 4 & beta from DF
%
beta = 0.94;    % beta is the probability that the choice coincides with
                % the one prescribed by the strategy.

% class 1
phi_ad = 0.23;     % fraction of AD - strg_choices = 1
phi_ac = 0.06;         % fraction of AC - strg_choices = 2
phi_grim = 0.04;       % fraction of Grim - strg_choices = 3
phi_tft = 0.07;      % fraction of TFT - strg_choices = 4
phi_stft = 0;      % fraction of STFT - strg_choices = 5
phi_wsls = 0;
phi_t2 = 0;
% class 2
% class 3
% class 4
phi_tf2t = 0.2;
phi_tf3t = 0.09;
phi_2tft = 0.03;
phi_2tf2t = 0.12;
phi_grim2 = 0.05;
phi_grim3 = 0.11;


phi = [phi_ad; phi_ac; phi_grim; phi_tft; phi_stft; phi_wsls; phi_t2;
       phi_tf2t; phi_tf3t; phi_2tft; phi_2tf2t; phi_grim2; phi_grim3];

%%%%%%%%%%%% LOOPING OVER SIMULATED DATA SETS %%%%%%%%%%%%%%%

% initializing variables
frac5_vec = zeros( no_simul , 1);
frac3_vec = zeros( no_simul , 1);

disp('Start Loop 6');
parfor i = 1:no_simul
    [ frac5, frac3 ] = sim_power_imp( no_session, no_subject, no_match, discount, phi, beta );
    if isnan(frac5)==1, frac5 = -1; end,    % This happens if no match is greater than 1 round
    if isnan(frac3)==1, frac3 = -1; end,
    frac5_vec(i,1) = frac5;
    frac3_vec(i,1) = frac3;
end
frac5_vec = frac5_vec(frac5_vec ~= -1); % drop the simulations where all matches have one round
frac3_vec = frac3_vec(frac3_vec ~= -1);

bc = 4*ones(size(frac5_vec));
beta_vec = beta*ones(size(frac5_vec));

output_bc_4b = [bc frac5_vec frac3_vec beta_vec];

clearvars -EXCEPT output_bc_2 output_bc_2p5 output_bc_4 output_bc_2b output_bc_2p5b output_bc_4b no_session no_subject no_match discount no_simul






%%%% Final Stuff %%%%


% Put the key data together
output = [output_bc_2; output_bc_2p5; output_bc_4;output_bc_2b; output_bc_2p5b; output_bc_4b];

% Report Key Info
disp(' ');
disp('-------------------');
disp(' ');
disp(sprintf('b/c = 2 mean mem 1 consitency with basic 3: %1.3f', mean( output_bc_2(:,3) ) ));
disp(' ');
disp(sprintf('b/c = 2 fraction of cases at or better than data for basic 3: %1.3f', mean( ( output_bc_2(:,3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');
disp(sprintf('b/c = 2.5 mean mem 1 consitency with basic 3: %1.3f', mean( output_bc_2p5(:,3) ) ));
disp(' ');
disp(sprintf('b/c = 2.5 fraction of cases at or better than data for basic 3: %1.3f', mean( ( output_bc_2p5(:,3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');
disp(sprintf('b/c = 4 mean mem 1 consitency with basic 3: %1.3f', mean( output_bc_4(:,3) ) ));
disp(' ');
disp(sprintf('b/c = 4 fraction of cases at or better than data for basic 3: %1.3f', mean( ( output_bc_4(:,3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');
disp(sprintf('Overall mean mem 1 consitency with basic 3: %1.3f', mean( output((output(:,4)~=0.94),3) ) ));
disp(' ');
disp(sprintf('Overall fraction of cases at or better than data for basic 3: %1.3f', mean( ( output((output(:,4)~=0.94),3) >= 0.7539063 ) ) ));
disp(' ');
disp('-------------------');
disp(' ');
disp(sprintf('b/c = 2 and beta from DF mean mem 1 consitency with basic 3: %1.3f', mean( output_bc_2b(:,3) ) ));
disp(' ');
disp(sprintf('b/c = 2 and beta from DF fraction of cases at or better than data for basic 3: %1.3f', mean( ( output_bc_2b(:,3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');
disp(sprintf('b/c = 2.5 and beta from DF mean mem 1 consitency with basic 3: %1.3f', mean( output_bc_2p5b(:,3) ) ));
disp(' ');
disp(sprintf('b/c = 2.5 and beta from DF fraction of cases at or better than data for basic 3: %1.3f', mean( ( output_bc_2p5b(:,3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');
disp(sprintf('b/c = 4 and beta from DF mean mem 1 consitency with basic 3: %1.3f', mean( output_bc_4b(:,3) ) ));
disp(' ');
disp(sprintf('b/c = 4 and beta from DF fraction of cases at or better than data for basic 3: %1.3f', mean( ( output_bc_4b(:,3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');
disp(sprintf('Overall (beta from DF) mean mem 1 consitency with basic 3: %1.3f', mean( output((output(:,4)==0.94),3) ) ));
disp(' ');
disp(sprintf('Overall (beta from DF) fraction of cases at or better than data for basic 3: %1.3f', mean( ( output((output(:,4)==0.94),3) >= 0.7539063 ) ) ));
disp(' ');
disp(' ');



toc

save('data/raw/sim_power_imp_5', 'output_bc_2', 'output_bc_2p5', 'output_bc_4', '-double', '-tabs')
save('data/raw/sim_power_imp_5.txt', 'output', '-ascii', '-double', '-tabs')

diary off

% Change log
% 07/12/16
%   - Based on sim_power_5.m to simulate Fudenberg et al. (2012) type data.

